==> haskell-th-reify-many-0.1.10-200-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-reify-many
version:              0.1.10
visibility:           public
id:                   th-reify-many-0.1.10-1Aa0pJ4zOdg4KmJuPSQaIQ
key:                  th-reify-many-0.1.10-1Aa0pJ4zOdg4KmJuPSQaIQ
license:              BSD-3-Clause
maintainer:           Michael Sloan <mgsloan at gmail>
author:               Michael Sloan
stability:            Experimental
homepage:             http://github.com/mgsloan/th-reify-many
synopsis:             Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.

category:             Template Haskell
abi:                  970fe84263fbb7b76d7f1c173ad685dc
exposed:              True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-reify-many-0.1.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-reify-many-0.1.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-reify-many-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-reify-many
hs-libraries:         HSth-reify-many-0.1.10-1Aa0pJ4zOdg4KmJuPSQaIQ
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    safe-0.3.21-Esyyru5CUzTFDSdkcA7Wuj template-haskell-2.19.0.0
    th-expand-syns-0.4.12.0-DcK5DeNH89JDSvbD9Ug1y6

haddock-interfaces:
    /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock

haddock-html:         /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-reify-many-0.1.10-201-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-reify-many
version:              0.1.10
visibility:           public
id:                   th-reify-many-0.1.10-5nVKxRxVqsFujlTdzKLx3
key:                  th-reify-many-0.1.10-5nVKxRxVqsFujlTdzKLx3
license:              BSD-3-Clause
maintainer:           Michael Sloan <mgsloan at gmail>
author:               Michael Sloan
stability:            Experimental
homepage:             http://github.com/mgsloan/th-reify-many
synopsis:             Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.

category:             Template Haskell
abi:                  a0d89686b1cf150610b854d1e82a9842
exposed:              True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-reify-many-0.1.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-reify-many-0.1.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-reify-many-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-reify-many
hs-libraries:         HSth-reify-many-0.1.10-5nVKxRxVqsFujlTdzKLx3
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    safe-0.3.21-h7eXfPvXuk1aMCYRfiuDr template-haskell-2.19.0.0
    th-expand-syns-0.4.12.0-FMOJmjREwuCGUm9eofl9QA

haddock-interfaces:
    /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock

haddock-html:         /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
